import { BaseResponseDto } from './base.response.dto';

export interface PageResponseDto {
  // Original paging information from the request ( or default )
  page: number;
  size: number;

  // Useful for display  (N Records found)
  totalItem: number;

  // Use for display N Pages ( 0... N )
  totalPage: number;

  // Has next is false when cursor is at last page
  hasNext: boolean;

  // Has previous is false when cursor is at first page
  hasPrevious: boolean;
}

export class PageResponse<T> implements BaseResponseDto, PageResponseDto {
  code?: number;

  message: string;

  data: Array<T>;

  page: number;

  size: number;

  totalItem: number;

  totalPage: number;

  hasNext: boolean;

  hasPrevious: boolean;

  constructor(
    baseResponseDto: BaseResponseDto,
    pageResponseDto: PageResponseDto,
  ) {
    if (baseResponseDto.statusCode) {
      this.code = baseResponseDto.statusCode;
    } else {
      this.code = 200;
    }

    if (baseResponseDto.data) {
      this.data = baseResponseDto.data;
    }

    this.message = baseResponseDto.message;
    this.page = pageResponseDto.page;
    this.size = pageResponseDto.size;
    this.totalItem = pageResponseDto.totalItem;
    this.totalPage = pageResponseDto.totalPage;
    this.hasNext = pageResponseDto.hasNext;
    this.hasPrevious = pageResponseDto.hasPrevious;
  }
}
