import { Injectable } from '@nestjs/common';
import { SqlLoaderService } from './sql-loader.service';
import { DataSource } from 'typeorm';
import { SQL_PROCEDURES_PATH } from '@app/common/constants/sql-query-path';

@Injectable()
export class PowerClampService {
  constructor(
    private readonly sqlLoader: SqlLoaderService,
    private readonly dataSource: DataSource,
  ) {}

  async updateEnergyConsumedHistoricalData(deviceUuid: string): Promise<void> {
    try {
      const now = new Date();
      const dateStr = now.toLocaleDateString('en-CA'); // YYYY-MM-DD
      const hour = now.getHours();
      const monthYear = now
        .toLocaleDateString('en-US', {
          month: '2-digit',
          year: 'numeric',
        })
        .replace('/', '-'); // MM-YYYY

      await this.executeProcedure(
        'fact_hourly_device_energy_consumed_procedure',
        [deviceUuid, dateStr, hour],
      );

      await this.executeProcedure(
        'fact_daily_device_energy_consumed_procedure',
        [deviceUuid, dateStr],
      );

      await this.executeProcedure(
        'fact_monthly_device_energy_consumed_procedure',
        [deviceUuid, monthYear],
      );
    } catch (err) {
      console.error('Failed to insert or update energy data:', err);
      throw err;
    }
  }

  private async executeProcedure(
    procedureFileName: string,
    params: (string | number | null)[],
  ): Promise<void> {
    const query = this.loadQuery(
      'fact_device_energy_consumed',
      procedureFileName,
    );
    await this.dataSource.query(query, params);
    console.log(`Procedure ${procedureFileName} executed successfully.`);
  }

  private loadQuery(folderName: string, fileName: string): string {
    return this.sqlLoader.loadQuery(folderName, fileName, SQL_PROCEDURES_PATH);
  }
}
