import { Column, Entity, ManyToOne, OneToMany, Unique } from 'typeorm';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';
import { DeviceEntity } from '../../device/entities/device.entity';
import { ProjectEntity } from '../../project/entities';
import { SpaceModelProductAllocationEntity } from '../../space-model/entities/space-model-product-allocation.entity';
import { SubspaceModelProductAllocationEntity } from '../../space-model/entities/subspace-model/subspace-model-product-allocation.entity';
import { NewTagDto } from '../dtos/tag.dto';

@Entity({ name: 'new_tag' })
@Unique(['name', 'project'])
export class NewTagEntity extends AbstractEntity<NewTagDto> {
  @Column({
    type: 'uuid',
    default: () => 'gen_random_uuid()',
    nullable: false,
  })
  public uuid: string;

  @Column({
    type: 'varchar',
    length: 255,
    nullable: true,
  })
  name: string;

  @ManyToOne(() => ProjectEntity, (project) => project.tags, {
    nullable: false,
    onDelete: 'CASCADE',
  })
  public project: ProjectEntity;

  @OneToMany(
    () => SpaceModelProductAllocationEntity,
    (allocation) => allocation.tag,
  )
  public spaceModelAllocations: SpaceModelProductAllocationEntity[];

  @OneToMany(
    () => SubspaceModelProductAllocationEntity,
    (allocation) => allocation.tag,
  )
  public subspaceModelAllocations: SubspaceModelProductAllocationEntity[];

  @OneToMany(() => DeviceEntity, (device) => device.tag)
  public devices: DeviceEntity[];

  constructor(partial: Partial<NewTagEntity>) {
    super();
    Object.assign(this, partial);
  }
}
