import { ApiProperty } from '@nestjs/swagger';
import { IsNotEmpty, IsString } from 'class-validator';

export class RegisterClientDto {
  @ApiProperty({
    example: 'SmartHomeApp',
    description: 'The name of the client',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  name: string;

  @ApiProperty({
    example: 'https://client-app.com/callback',
    description: 'The redirect URI of the client',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  redirectUri: string;

  @ApiProperty({
    example: ['DEVICE_SINGLE_CONTROL', 'DEVICE_VIEW'],
    description: 'The scopes of the client',
    required: true,
  })
  @IsString({ each: true })
  @IsNotEmpty({ each: true })
  scopes: string[];
}
