import {
  Body,
  Controller,
  Delete,
  Get,
  HttpStatus,
  Param,
  Post,
  UseGuards,
} from '@nestjs/common';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { DeviceMessagesSubscriptionService } from '../services/device-messages.service';
import { DeviceMessagesAddDto } from '../dtos/device-messages.dto';

import { JwtAuthGuard } from '@app/common/guards/jwt.auth.guard';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { ControllerRoute } from '@app/common/constants/controller-route';

@ApiTags('Device Messages Status Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.DEVICE_MESSAGES_SUBSCRIPTION.ROUTE,
})
export class DeviceMessagesSubscriptionController {
  constructor(
    private readonly deviceMessagesSubscriptionService: DeviceMessagesSubscriptionService,
  ) {}

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Post()
  @ApiOperation({
    summary:
      ControllerRoute.DEVICE_MESSAGES_SUBSCRIPTION.ACTIONS
        .ADD_DEVICE_MESSAGES_SUBSCRIPTION_SUMMARY,
    description:
      ControllerRoute.DEVICE_MESSAGES_SUBSCRIPTION.ACTIONS
        .ADD_DEVICE_MESSAGES_SUBSCRIPTION_DESCRIPTION,
  })
  async addDeviceMessagesSubscription(
    @Body() deviceMessagesAddDto: DeviceMessagesAddDto,
  ) {
    const addDetails =
      await this.deviceMessagesSubscriptionService.addDeviceMessagesSubscription(
        deviceMessagesAddDto,
      );
    return {
      statusCode: HttpStatus.CREATED,
      message: 'Device Messages Subscription Added Successfully',
      data: addDetails,
    };
  }

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Get(':deviceUuid/user/:userUuid')
  @ApiOperation({
    summary:
      ControllerRoute.DEVICE_MESSAGES_SUBSCRIPTION.ACTIONS
        .GET_DEVICE_MESSAGES_SUBSCRIPTION_SUMMARY,
    description:
      ControllerRoute.DEVICE_MESSAGES_SUBSCRIPTION.ACTIONS
        .GET_DEVICE_MESSAGES_SUBSCRIPTION_DESCRIPTION,
  })
  async getDeviceMessagesSubscription(
    @Param('deviceUuid') deviceUuid: string,
    @Param('userUuid') userUuid: string,
  ) {
    const deviceDetails =
      await this.deviceMessagesSubscriptionService.getDeviceMessagesSubscription(
        userUuid,
        deviceUuid,
      );
    return {
      statusCode: HttpStatus.OK,
      message: 'User Device Subscription fetched Successfully',
      data: deviceDetails,
    };
  }

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Delete()
  @ApiOperation({
    summary:
      ControllerRoute.DEVICE_MESSAGES_SUBSCRIPTION.ACTIONS
        .DELETE_DEVICE_MESSAGES_SUBSCRIPTION_SUMMARY,
    description:
      ControllerRoute.DEVICE_MESSAGES_SUBSCRIPTION.ACTIONS
        .DELETE_DEVICE_MESSAGES_SUBSCRIPTION_DESCRIPTION,
  })
  async deleteDeviceMessagesSubscription(
    @Body() deviceMessagesAddDto: DeviceMessagesAddDto,
  ) {
    await this.deviceMessagesSubscriptionService.deleteDeviceMessagesSubscription(
      deviceMessagesAddDto,
    );
    return {
      statusCode: HttpStatus.OK,
      message: 'User subscription deleted Successfully',
    };
  }
}
