import { BatchDeviceTypeEnum } from '@app/common/constants/batch-device.enum';
import { ApiProperty } from '@nestjs/swagger';
import {
  IsArray,
  IsEnum,
  IsNotEmpty,
  IsOptional,
  IsString,
} from 'class-validator';

export class ControlDeviceDto {
  @ApiProperty({
    description: 'code',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public code: string;
  @ApiProperty({
    description: 'value',
    required: true,
  })
  @IsNotEmpty()
  public value: any;
}
export class BatchControlDevicesDto {
  @ApiProperty({
    description: 'Operation type',
    enum: BatchDeviceTypeEnum,
    required: true,
  })
  @IsEnum(BatchDeviceTypeEnum)
  @IsNotEmpty()
  public operationType: BatchDeviceTypeEnum;

  @ApiProperty({
    description: 'devicesUuid',
    required: true,
  })
  @IsArray()
  @IsNotEmpty()
  public devicesUuid: [string];
  @ApiProperty({
    description: 'code',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public code: string;
  @ApiProperty({
    description: 'value',
    required: true,
  })
  @IsNotEmpty()
  public value: any;
}
export class BatchStatusDevicesDto {
  @ApiProperty({
    example: 'uuid1,uuid2,uuid3',
    description: 'Comma-separated list of device UUIDs',
  })
  devicesUuid: string;
}
export class BatchFactoryResetDevicesDto {
  @ApiProperty({
    description: 'devicesUuid',
    required: true,
  })
  @IsArray()
  @IsNotEmpty()
  public devicesUuid: [string];
}
export class GetSceneFourSceneDeviceDto {
  @ApiProperty({
    description: 'switchName',
    required: false,
  })
  @IsString()
  @IsOptional()
  public switchName?: string;
}
