import { RoleType } from '@app/common/constants/role.type.enum';
import { CommunityPermissionService } from '@app/common/helper/services/community.permission.service';
import {
  BadRequestException,
  CanActivate,
  ExecutionContext,
  Injectable,
} from '@nestjs/common';

@Injectable()
export class CommunityPermissionGuard implements CanActivate {
  constructor(private readonly permissionService: CommunityPermissionService) {}

  async canActivate(context: ExecutionContext): Promise<boolean> {
    const req = context.switchToHttp().getRequest();

    try {
      const { communityUuid } = req.params;
      const { user } = req;

      if (
        user &&
        user.role &&
        !(
          user.role.type === RoleType.ADMIN ||
          user.role.type === RoleType.SUPER_ADMIN
        )
      ) {
        return true;
      }

      if (!communityUuid) {
        throw new BadRequestException('communityUuid is required');
      }

      await this.permissionService.checkUserPermission(communityUuid);

      return true;
    } catch (error) {
      throw error;
    }
  }
}
