import { SpacePermissionService } from '@app/common/helper/services/space.permission.service';
import {
  BadRequestException,
  CanActivate,
  ExecutionContext,
  Injectable,
} from '@nestjs/common';

@Injectable()
export class UnitPermissionGuard implements CanActivate {
  constructor(private readonly permissionService: SpacePermissionService) {}

  async canActivate(context: ExecutionContext): Promise<boolean> {
    const req = context.switchToHttp().getRequest();

    try {
      const { unitUuid } = req.params;
      const { user } = req;

      if (!unitUuid) {
        throw new BadRequestException('unitUuid is required');
      }

      await this.permissionService.checkUserPermission(unitUuid, user.uuid);

      return true;
    } catch (error) {
      throw error;
    }
  }
}
