import { DeviceStatusFirebaseService } from '@app/common/firebase/devices-status/services/devices-status.service';
import { AqiDataService } from '@app/common/helper/services/aqi.data.service';
import { OccupancyService } from '@app/common/helper/services/occupancy.service';
import { PowerClampService } from '@app/common/helper/services/power.clamp.service';
import { SqlLoaderService } from '@app/common/helper/services/sql-loader.service';
import { TuyaService } from '@app/common/integrations/tuya/services/tuya.service';
import { AutomationRepository } from '@app/common/modules/automation/repositories';
import { CommunityRepository } from '@app/common/modules/community/repositories';
import { DeviceStatusLogRepository } from '@app/common/modules/device-status-log/repositories';
import { DeviceRepository } from '@app/common/modules/device/repositories';
import { InviteUserRepository } from '@app/common/modules/Invite-user/repositiories';
import {
  PowerClampDailyRepository,
  PowerClampHourlyRepository,
  PowerClampMonthlyRepository,
} from '@app/common/modules/power-clamp/repositories';
import { ProductRepository } from '@app/common/modules/product/repositories';
import { ProjectRepository } from '@app/common/modules/project/repositiories';
import { SceneDeviceRepository } from '@app/common/modules/scene-device/repositories';
import {
  SceneIconRepository,
  SceneRepository,
} from '@app/common/modules/scene/repositories';
import {
  InviteSpaceRepository,
  SpaceLinkRepository,
  SpaceProductAllocationRepository,
  SpaceRepository,
} from '@app/common/modules/space';
import {
  SpaceModelProductAllocationRepoitory,
  SpaceModelRepository,
  SubspaceModelProductAllocationRepoitory,
  SubspaceModelRepository,
} from '@app/common/modules/space-model';
import {
  SubspaceProductAllocationRepository,
  SubspaceRepository,
} from '@app/common/modules/space/repositories/subspace.repository';
import { NewTagRepository } from '@app/common/modules/tag/repositories/tag-repository';
import {
  UserRepository,
  UserSpaceRepository,
} from '@app/common/modules/user/repositories';
import { Global, Module } from '@nestjs/common';
import { CqrsModule } from '@nestjs/cqrs';
import { CommunityService } from 'src/community/services';
import { DeviceService } from 'src/device/services';
import { SceneService } from 'src/scene/services';
import {
  SpaceModelService,
  SubSpaceModelService,
} from 'src/space-model/services';
import { SpaceModelProductAllocationService } from 'src/space-model/services/space-model-product-allocation.service';
import { SubspaceModelProductAllocationService } from 'src/space-model/services/subspace/subspace-model-product-allocation.service';
import {
  SpaceLinkService,
  SpaceService,
  SubspaceDeviceService,
  SubSpaceService,
  ValidationService,
} from 'src/space/services';
import { SpaceProductAllocationService } from 'src/space/services/space-product-allocation.service';
import { SubspaceProductAllocationService } from 'src/space/services/subspace/subspace-product-allocation.service';
import { TagService } from 'src/tags/services';
import { ProjectController } from './controllers';
import { ProjectUserController } from './controllers/project-user.controller';
import { CreateOrphanSpaceHandler } from './handler';
import { ProjectService } from './services';
import { ProjectUserService } from './services/project-user.service';

const CommandHandlers = [CreateOrphanSpaceHandler];

@Global()
@Module({
  imports: [CqrsModule],
  controllers: [ProjectController, ProjectUserController],
  providers: [
    ...CommandHandlers,
    SpaceRepository,
    CommunityRepository,
    ProjectService,
    ProjectUserService,
    ProjectRepository,
    InviteUserRepository,
    UserSpaceRepository,
    UserRepository,
    SpaceService,
    InviteSpaceRepository,
    SpaceLinkService,
    SubSpaceService,
    ValidationService,
    TagService,
    SpaceModelService,
    DeviceService,
    SpaceProductAllocationService,
    SpaceLinkRepository,
    SubspaceRepository,
    SubspaceDeviceService,
    SubspaceProductAllocationService,
    CommunityService,
    SpaceModelRepository,
    DeviceRepository,
    NewTagRepository,
    ProductRepository,
    SubSpaceModelService,
    SpaceModelProductAllocationService,
    SpaceProductAllocationRepository,
    SubspaceProductAllocationRepository,
    SceneDeviceRepository,
    DeviceStatusFirebaseService,
    SceneService,
    TuyaService,
    SubspaceModelRepository,
    SubspaceModelProductAllocationService,
    SpaceModelProductAllocationRepoitory,
    DeviceStatusLogRepository,
    SceneIconRepository,
    SceneRepository,
    AutomationRepository,
    SubspaceModelProductAllocationRepoitory,
    PowerClampService,
    PowerClampHourlyRepository,
    PowerClampDailyRepository,
    PowerClampMonthlyRepository,
    SqlLoaderService,
    OccupancyService,
    AqiDataService,
  ],
  exports: [ProjectService, CqrsModule],
})
export class ProjectModule {}
