import {
  BadRequestException,
  HttpException,
  HttpStatus,
  Inject,
  Injectable,
} from '@nestjs/common';
import { RegionRepository } from '@app/common/modules/region/repositories';
import { ErrorMessageService } from 'src/error-message/error-message.service';

@Injectable()
export class RegionService {
  constructor(
    private readonly regionRepository: RegionRepository,
    @Inject(ErrorMessageService)
    private readonly errorMessageService: ErrorMessageService,
  ) {}
  async getAllRegions() {
    try {
      const regions = await this.regionRepository.find();
      return regions;
    } catch (err) {
      if (err instanceof BadRequestException) {
        throw err; // Re-throw BadRequestException
      } else {
        throw new HttpException(
          this.errorMessageService.getMessage('NOT_FOUND', {
            entity: 'Regions',
          }),
          HttpStatus.NOT_FOUND,
        );
      }
    }
  }
}
