import { WorkingDays } from '@app/common/constants/working-days';
import { ApiProperty } from '@nestjs/swagger';
import { Type } from 'class-transformer';
import {
  IsArray,
  IsBoolean,
  IsEnum,
  IsNotEmpty,
  IsString,
  ValidateNested,
} from 'class-validator';
export class FunctionDto {
  @ApiProperty({
    description: 'code',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public code: string;

  @ApiProperty({
    description: 'value',
    required: true,
  })
  @IsNotEmpty()
  public value: any;
}

// Update the main DTO class
export class AddScheduleDto {
  @ApiProperty({
    description: 'category',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public category: string;

  @ApiProperty({
    description: 'time',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public time: string;

  @ApiProperty({
    description: 'function',
    required: true,
    type: FunctionDto,
  })
  @ValidateNested()
  @Type(() => FunctionDto)
  public function: FunctionDto;

  @ApiProperty({
    description: 'days',
    enum: WorkingDays,
    isArray: true,
    required: true,
  })
  @IsArray()
  @IsEnum(WorkingDays, { each: true })
  @IsNotEmpty()
  public days: WorkingDays[];
}

export class EnableScheduleDto {
  @ApiProperty({
    description: 'scheduleId',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public scheduleId: string;

  @ApiProperty({
    description: 'enable',
    required: true,
  })
  @IsBoolean()
  @IsNotEmpty()
  public enable: boolean;
}
export class GetScheduleDeviceDto {
  @ApiProperty({
    description: 'category',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public category: string;
}

export class UpdateScheduleDto {
  @ApiProperty({
    description: 'scheduleId',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public scheduleId: string;
  @ApiProperty({
    description: 'category',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public category: string;

  @ApiProperty({
    description: 'time',
    required: true,
  })
  @IsString()
  @IsNotEmpty()
  public time: string;

  @ApiProperty({
    description: 'function',
    required: true,
    type: FunctionDto,
  })
  @ValidateNested()
  @Type(() => FunctionDto)
  public function: FunctionDto;

  @ApiProperty({
    description: 'days',
    enum: WorkingDays,
    isArray: true,
    required: true,
  })
  @IsArray()
  @IsEnum(WorkingDays, { each: true })
  @IsNotEmpty()
  public days: WorkingDays[];
}
