import { ApiProperty } from '@nestjs/swagger';
import { Type } from 'class-transformer';
import { IsArray, IsNotEmpty, IsString, ValidateNested } from 'class-validator';
import { CreateTagDto } from './tags.dto';

export class BulkCreateTagsDto {
  @ApiProperty({
    description: 'Project UUID for which the tags are being created',
    example: '760e8400-e29b-41d4-a716-446655440001',
  })
  @IsNotEmpty()
  @IsString()
  projectUuid: string;

  @ApiProperty({
    description: 'List of tags to be created',
    type: [CreateTagDto],
  })
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => CreateTagDto)
  tags: CreateTagDto[];
}
