import { Controller, Get, UseGuards } from '@nestjs/common';
import { TimeZoneService } from '../services/timezone.service';
import { ApiTags, ApiBearerAuth, ApiOperation } from '@nestjs/swagger';
import { JwtAuthGuard } from '../../../libs/common/src/guards/jwt.auth.guard';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { ControllerRoute } from '@app/common/constants/controller-route';

@ApiTags('TimeZone Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.TIMEZONE.ROUTE,
})
export class TimeZoneController {
  constructor(private readonly timeZoneService: TimeZoneService) {}

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Get()
  @ApiOperation({
    summary: ControllerRoute.TIMEZONE.ACTIONS.GET_ALL_TIME_ZONES_SUMMARY,
    description:
      ControllerRoute.TIMEZONE.ACTIONS.GET_ALL_TIME_ZONES_DESCRIPTION,
  })
  async getAllTimeZones() {
    return await this.timeZoneService.getAllTimeZones();
  }
}
